@@ -1,9 +1,9 @@
 #!/usr/bin/perl
 
 use strict;
-use Lingua::Stem::Snowball::Norwegian;
+use Lingua::Stem::Snowball::No;
 
-my $stemmer = new Lingua::Stem::Snowball::Norwegian (use_cache => 1);
+my $stemmer = new Lingua::Stem::Snowball::No(use_cache => 1);
 while(my $line = <>) {
 	chomp $line;
 	foreach my $word (split /\s+/, $line) {
